@@ -6,7 +6,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_dir);
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 # now moved to Setup::File
 
@@ -17,17 +17,21 @@ sub setup_dir {
 1;
 # ABSTRACT: Setup directory (existence, mode, permission)
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Setup::File::Dir - Setup directory (existence, mode, permission)
 
 =head1 VERSION
 
-version 0.17
+This document describes version 0.18 of Setup::File::Dir (from Perl distribution Setup-File), released on 2014-05-02.
+
+=for Pod::Coverage ^(setup_dir)$
 
 =head1
 
@@ -39,15 +43,21 @@ L<Setup>
 
 L<Setup::File>
 
-=head1 DESCRIPTION
+=head1 HOMEPAGE
 
+Please visit the project's homepage at L<https://metacpan.org/release/Setup-File>.
 
-This module has L<Rinci> metadata.
+=head1 SOURCE
 
-=head1 FUNCTIONS
+Source repository is at L<https://github.com/sharyanto/perl-Setup-File>.
 
+=head1 BUGS
 
-None are exported by default, but they are exportable.
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Setup-File>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -55,10 +65,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
